%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% File:        uerj_desc.cls
% 
% Written by:  Elaine de M. Silva
%      (based on previous versions by José Carlos L. Ralha and 
%                                      Flávio Maico Vaz da Costa)
% 
% Version: 1.0 
% Date:        May 2, 2009
% 
% Purpose: LaTeX 2e undergraduate monograph class for the system and computer
%          engineering course, UERJ.  
% 
% Notes:   The uerj_desc class is based on the standard report class.  This
%          class was written based on the unb-cic.cls class by José Carlos L. Ralha
%          and Flávio Maico Vaz da Costa. 
%          Some ideas were also taken from coppeThesis.cls, written by 
%          J. Russell Noseworthy and adapted by Fernando Lizarralde.              
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                              MODIFICATION LOG:
%   May 2, 2009 - added this mod log.
%
%
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{uerj_desc}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}
\DeclareOption{harvard}{

  \AtEndOfPackage{
    % carrega pacote harvard
    \RequirePackage{harvard}

    \citationmode{abbr}
    \citationstyle{dcu}
    \bibliographystyle{dcu}
  }
}
\ProcessOptions
\LoadClass[a4paper]{report}
\RequirePackage[latin1]{inputenc}
\RequirePackage{keyval}
\RequirePackage{lastpage}
\RequirePackage{ifthen}
\RequirePackage{vmargin}
\RequirePackage{graphicx}

%definicoes para páginas obrigatórias
\def\@departamento{Departamento de Sistemas e Computa\c{c}\~{a}o}
\def\@faculdade{Faculdade de Engenharia}
\def\@universidade{Universidade do Estado do Rio de Janeiro}
\def\@siglauni{UERJ}
\def\@siglafac{FEN}
\def\@grau{Engenheiro}
\def\@graucompleto{Engenheiro Eletricista com \^{e}nfase em Sistemas e Computa\c{c}\~{a}o}
\def\@curso{Engenharia El\'{e}trica - \^{e}nfase em Sistemas e Computa\c{c}\~{a}o}
\def\@cidade{Rio de Janeiro}
\def\@uf{RJ}
\def\@cidadeuf{\@cidade--\@uf}
\def\@pais{Brasil}
\def\@tipo{Monografia}
\def\@formatocapa{29,7 cm}

%para imprimir o titulo
\def\@imprimetitulo{%
\@title
}

%define mes e ano
\def\diamesano#1#2#3{%
\def\@dia{#1}%
\def\@mes{#2}%
\def\@ano{#3}%
}


\renewcommand{\baselinestretch}{1.5}

%definicao do autor
\newcommand{\autor}[2]{
	\def\primeiroautor{#1\ #2}% Único autor em ordem Prenome Nome
	\def\primeiroautorinv{#2,\ #1}% Único autor em ordem Nome, Prenome
	\author{\primeiroautor}
} 

%definicao do orientador
\newcommand{\orientador}[3]{
	\def\@orientadornome{#1}%
	\def\@orientadortitulacao{#2}%	
	\def\@orientadorinstituicao{#3}%	
} 


\newboolean{ifcoorientador}\setboolean{ifcoorientador}{false}
%definicao do coorientador, se houver
\newcommand{\coorientador}[3]{
	\setboolean{ifcoorientador}{true}
	\def\@coorientadornome{#1}%
	\def\@coorientadortitulacao{#2}%	
	\def\@coorientadorinstituicao{#3}%	
}

%definicao do primeiro membro da banca
\newcommand{\bancaum}[3]{
	\def\@bancaumnome{#1}%
	\def\@bancaumtitulacao{#2}%	
	\def\@bancauminstituicao{#3}%	
}


\newboolean{bancadois}\setboolean{bancadois}{false}
%definicao do segundo membro da banca, se houver
\newcommand{\bancadois}[3]{
\setboolean{bancadois}{true}
	\def\@bancadoisnome{#1}%
	\def\@bancadoistitulacao{#2}%	
	\def\@bancadoisinstituicao{#3}%	
}


%definicao de  palavras-chave - para ficha catalografica e resumo/abstract
\newcommand*{\keywords}{\@dblarg\set@keywords}
\newcommand*{\set@keywords}[2][]{%
	\gdef\@keywords{#1}
	\gdef\@@keywords{#2}
}
\newcommand*{\palavraschave}{\@dblarg\set@palavraschave}
\newcommand*{\set@palavraschave}[2][]{%
	\gdef\@palavraschave{#1}
	\gdef\@@palavraschave{#2}
}


%numera as palavras-chave para a ficha catalográfica
\def\numerarcip#1{
	\newcounter{cipcount} \edef\more{#1}
  \begin{flushleft}%
  \ifx\more\empty\else\expandafter\numerarcipr\more,\@nil\fi
  \end{flushleft}%
}
\def\numerarcipr#1,#2\@nil{
	\stepcounter{cipcount} \def\more{#2}
	\thecipcount.~#1\ifx\more\empty\else,\numerarcipr#2\@nil\fi
}


%Escolhe fonte . Opcoes:
% 1 - phv - helvetica 
%     cmr - computer modern roman
%     ptm - times new roman
%     ppl - palatino
%     pcr - courier
%     pbk - bookman
%     put - utopia 
% para uma lista mais completa, acesse 
% http://www-h.eng.cam.ac.uk/help/tpl/textprocessing/latex_advanced/node18.html#LJMR1LIST
% 2 - b- bold, m- medium, c - condensed
% 3 - size: 
% 4 - it -> italico, n-> normal, sl-> obliquo, sc-> caixa alta

\newenvironment{usemyfont}[4]{
\fontencoding{T1}
  \fontfamily{#1}
  \fontseries{#2}
  \fontshape{#4}
  \fontsize{#3}{15}
  \selectfont

}


%define tipos de fonte padrao - regular
\newcommand\fontregular{
\fontencoding{T1}
\fontfamily{phv}
\fontseries{m}
\fontshape{n}
\fontsize{16}{12}
\selectfont
}

%define tipos de fonte padrao - header de capitulo
\newcommand\fontchapter{
\fontencoding{T1}
\fontfamily{phv}
\fontseries{b}
\fontshape{sc}
\fontsize{18}{12}
\selectfont
}

%define tipos de fonte padrao - header de secao
\newcommand\fontsection{
\fontencoding{T1}
\fontfamily{phv}
\fontseries{b}
\fontshape{n}
\fontsize{16}{12}
\selectfont
}

%define tipos de fonte padrao - header de subsecao
\newcommand\fontsubsection{
\fontencoding{T1}
\fontfamily{phv}
\fontseries{b}
\fontshape{n}
\fontsize{14}{12}
\selectfont
}

%define tipos de fonte padrao - header de subsubsecao
\newcommand\fontsubsubsection{
\fontencoding{T1}
\fontfamily{phv}
\fontseries{b}
\fontshape{n}
\fontsize{13}{12}
\selectfont
}

%define tipos de fonte padrao - header de paragrafo
\newcommand\fontparagraph{
\fontencoding{T1}
\fontfamily{phv}
\fontseries{b}
\fontshape{n}
\fontsize{13}{12}
\selectfont
}  
  

% redefine header dos capitulos
\renewcommand\chapter{\if@openright\cleardoublepage\else\clearpage\fi
                    \thispagestyle{plain}%
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
\def\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
                         \refstepcounter{chapter}%
                         \typeout{\@chapapp\space\thechapter.}%
                         \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\thechapter}#1}%
                    \else
                      \addcontentsline{toc}{chapter}{#1}%
                    \fi
                    \chaptermark{#1}%
                    \addtocontents{lof}{\protect\addvspace{10\p@}}%
                    \addtocontents{lot}{\protect\addvspace{10\p@}}%
                    \if@twocolumn
                      \@topnewpage[\@makechapterhead{#2}]%
                    \else
                      \@makechapterhead{#2}%
                      \@afterheading
                    \fi}
\def\@makechapterhead#1{%
  \vspace*{50\p@}%
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
        \fontchapter \@chapapp\space \thechapter
        \par\nobreak
        \vskip 20\p@
    \fi
    \interlinepenalty\@M
     \fontchapter #1\par\nobreak
    \vskip 40\p@
  }}
  
%para capitulos nao numerados  
\def\@schapter#1{\if@twocolumn
                   \@topnewpage[\@makeschapterhead{#1}]%
                 \else
                   \@makeschapterhead{#1}%
                   \@afterheading
                 \fi}
\def\@makeschapterhead#1{%
  \vspace*{50\p@}%
  {\parindent \z@ \raggedright
    \normalfont
    \interlinepenalty\@M
   \fontchapter  #1\par\nobreak
    \vskip 40\p@
  }}
  

% redefine header das sessoes, subsessoes...   
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                 {-3.5ex \@plus -1ex \@minus -.2ex}%
                                 {2.3ex \@plus.2ex}%
                                 {\fontsection}}
                                                               
\renewcommand\subsection{\@startsection
{subsection}
{2}
{0mm}%
 {-\baselineskip}%            % the before skip
{0.5\baselineskip}%          % the after skip
{\fontsubsection}}
                                     
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\fontsubsubsection}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {3.25ex \@plus1ex \@minus.2ex}%
                                    {-1em}%
                                    {\fontparagraph}}
                                      
                                       
  
%definicao de pagina COM numeracao
\newenvironment{paginaComNum}
	{\cleardoublepage\thispagestyle{plain}}

%definicao de pagina SEM numeracao
\newenvironment{paginaSemNum}
	{\cleardoublepage\thispagestyle{empty}}
	
	
%define agradecimentos e insere bookmark
\newenvironment{agradecimentos}
	{\begin{paginaComNum}%
     	\pdfbookmark{Agradecimentos}{acknowledgements}%
   		\chapter*{Agradecimentos}}%
	{\end{paginaComNum}}


% para resumo em inglês - Abstract
\renewenvironment{abstract}
	{\begin{paginaComNum}%
    	\begin{otherlanguage*}{english}
        	\pdfbookmark{Abstract}{abstract}%
    		\chapter*{Abstract}}%
    		{\vskip 15pt\noindent\textbf{Keywords:}\ \@@keywords%
     	\end{otherlanguage*} 
	\end{paginaComNum}}


% define resumo, insere bookmark
\newenvironment{resumo}{
\begin{paginaComNum}%
	\pdfbookmark{\abstractname}{resumo}
\begin{usemyfont}{ptm}{m}{12}{n} 
\noindent Resumo da Monografia apresentada \`{a} \@siglafac/\@siglauni \hspace{1pt} como parte dos requisitos necess\'{a}rios para\\
a obten\c{c}\~{a}o  do grau de \@graucompleto. 
\end{usemyfont}
	\begin{center}
	
\begin{usemyfont}{ptm}{b}{14}{sc} 
	\vspace{3cm}%
     \@imprimetitulo
\end{usemyfont}

		\begin{usemyfont}{ptm}{m}{13}{n} 
			\vskip 1cm \@author
		\end{usemyfont}

    	\begin{usemyfont}{ptm}{m}{12}{n} 
			\vskip 0.3cm \@mes/\@ano
		\end{usemyfont}
	
	\end{center}
		
	\vskip 0.5cm	
	\noindent
	
	\begin{usemyfont}{ptm}{m}{12}{n}
		\noindent Orientador: \@orientadornome,\@orientadorinstituicao
		
		\ifthenelse{\boolean{ifcoorientador}}%
			{\noindent Co-orientador: \@coorientadornome,\@coorientadorinstituicao}\\
	\end{usemyfont}
		
 \vskip 15pt\noindent\textbf{Palavras-chave:}\ \@@palavraschave\\

\end{paginaComNum}}


% define dedicatoria, insere bookmark
\newenvironment{dedicatoria}{
	\begin{paginaComNum}%
			\pdfbookmark{Dedicat\'oria}{dedication}%
	 \end{paginaComNum}}%
	 

%define capa e insere bookmark
\newcommand\capa{

	\begin{paginaSemNum}%
	\pdfbookmark{Capa}{title}%
	\begin{minipage}{0.05\linewidth}
	\begin{flushleft}
  		\rule{0.15cm}{22cm}
  \end{flushleft}  
	\end{minipage}%	
\begin{minipage}{0.9\linewidth}
	\begin{usemyfont}{phv}{b}{16}{n}
	 \noindent
    \@universidade\\
    \@faculdade\\
    \@departamento\\
   \end{usemyfont}
	\begin{usemyfont}{phv}{b}{18}{sc} 
		\begin{center}%
			\vspace{3cm}%
      	\@imprimetitulo
		\end{center}%
	\end{usemyfont}
	\begin{usemyfont}{phv}{b}{16}{sc}     
		\begin{center}
			\vspace{3cm}%
			{\fontregular Autor: }\@author\\
		\end{center}%
	\end{usemyfont}
	\vspace{5cm}%
	\begin{usemyfont}{phv}{m}{14}{sc}       
		\begin{center}
			\@cidade\\
			\@mes/\@ano\\
		\end{center}%
	\end{usemyfont}
\end{minipage}
 \end{paginaSemNum}%
}

%pagina em branco COM numeracao
\def\paginabrancoComNum{
\begin{paginaComNum}

\newpage
~
\newpage

\end{paginaComNum}
}

%pagina em branco SEM numeracao
\def\paginabrancoSemNum{
\begin{paginaSemNum}

\newpage
~
\newpage

\end{paginaSemNum}
}

%ficha catalografica
\def\ficha{
	\begin{paginaSemNum}%
	\pdfbookmark{Ficha catalogr\'{a}fica}{title1}%
	\begin{center}		
		\begin{usemyfont}{ptm}{m}{13}{n}       
 			

					\@mes \hspace{1pt}--\@ano\\
				
			\end{usemyfont}
	
	\end{center}
	
		\begin{center}		
	\begin{minipage}{200pt}
	
        % imprime cidade, mes e ano 
        \vspace{5cm}

			\begin{usemyfont}{ptm}{m}{12}{sc}
			
					\primeiroautorinv
				
			\end{usemyfont}	
			
			\begin{usemyfont}{ptm}{m}{12}{n}       
 		\hspace{10.5pt}
					\@imprimetitulo\hspace{1pt}
					[\@cidade]\hspace{1pt} \@ano.
					
		\hspace{10.5pt}
 		xii, \pageref{LastPage} p. \@formatocapa\hspace{1pt} (\@siglafac/\@siglauni,
		\@grau, \@curso, \@ano)
		
		\hspace{10.5pt}
		\@tipo\hspace{1pt} - \@universidade\hspace{1pt} -- \@siglauni
		\numerarcip{\@palavraschave}
		
		I. \@siglafac/\@siglauni \hspace{8pt}  II.T\'{i}tulo\hspace{1pt}(s\'{e}rie) 
		
		
		
					\end{usemyfont}
			
			
	
\end{minipage}
	\end{center}%
 	\end{paginaSemNum}%
 	

		
}


%folha de julgamento

\def\folhajulgamento{

\begin{paginaSemNum}%
	\pdfbookmark{Folha de julgamento}{title2}%
	\begin{center}
		\begin{usemyfont}{phv}{b}{16}{sc}
 			\@imprimetitulo
		\end{usemyfont}
      \vspace{2cm}%
      \begin{usemyfont}{phv}{m}{14}{n}
			\primeiroautor
		\end{usemyfont}	
	\end{center}
	
\begin{usemyfont}{ptm}{m}{12}{n}
Monografia submetida ao corpo docente da \@faculdade\hspace{1pt} da \@universidade \hspace{1pt} - \@siglauni,
como parte dos requisitos necess\'{a}rios \`{a} obten\c{c}\~{a}o do diploma de \@graucompleto.
\end{usemyfont}	

\vspace{1cm}%
\begin{usemyfont}{ptm}{m}{13}{n}
Aprovada por:
\end{usemyfont}	

\vspace{1cm}%
\begin{usemyfont}{ptm}{m}{12}{n}
	\begin{flushright}
		\rule{10cm}{0.00125cm}\\
		Orientador: \@orientadornome, \@orientadortitulacao, \@orientadorinstituicao\\[1cm]
	
		\ifthenelse{\boolean{ifcoorientador}}%
			{\rule{10cm}{0.00125cm}\\
			Co-orientador: \@coorientadornome, \@coorientadortitulacao, \@coorientadorinstituicao\\[1cm]}

		\rule{10cm}{0.00125cm}\\
		Membro da banca: \@bancaumnome, \@bancaumtitulacao, \@bancauminstituicao\\[1cm]
		
		\ifthenelse{\boolean{bancadois}}%
			{\rule{10cm}{0.00125cm}\\
			Membro da banca: \@bancadoisnome, \@bancadoistitulacao, \@bancadoisinstituicao\\[1cm]}

	\end{flushright}

\end{usemyfont}

\begin{center}
\vspace{2cm}%
		\begin{usemyfont}{ptm}{m}{12}{n}
 		Rio de Janeiro, \@dia\hspace{1pt} de \@mes\hspace{1pt} de \@ano.
		\end{usemyfont}	
\end{center}

\end{paginaSemNum}

}


\endinput


